package com.muyu.common.caffeine.utils;


import com.github.benmanes.caffeine.cache.Cache;
import com.github.benmanes.caffeine.cache.Caffeine;
import com.muyu.common.caffeine.constents.CaffeineContent;
import com.muyu.common.redis.service.RedisService;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.cache.CacheManager;
import org.springframework.cache.caffeine.CaffeineCache;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Collection;

/**
 * Caffeine缓存工具
 * @Author: 胡杨
 * @Name: CaffeineUtils
 * @Description: 缓存工具类
 * @CreatedDate: 2024/9/26 下午2:53
 * @FilePath: com.muyu.common.caffeine
 */
@Slf4j
@Component
public class CaffeineCacheUtils {
    @Resource
    private RedisService redisService;
    @Resource
    private CacheManager cacheManager;


//    /**
//     * 车辆上线 - 新增缓存
//     */
//    public void addCarCache(String vin) {
//
//        ArrayList<CaffeineCache> caches = new ArrayList<>();
//        // 从Redis中获取缓存信息
//        Collection<String> keys = redisTemplate.keys(CaffeineContent.CAR_VIN_KEY + vin);
//        keys.forEach(key -> {
//            Object string = redisTemplate.opsForValue().get(key);
//            Cache<Object , Object> cache = Caffeine.newBuilder().build();
//            cache.put(key, string);
//            // 全部存储到 CaffeineCache集合
//            caches.add(new CaffeineCache(vin, cache));
//            log.info("存储缓存,vin:{}, key:{}, value:{}", vin, key, string);
//        });
//        simpleCacheManager.setCaches(caches);
//        log.info("车辆编码:{},本地缓存完成...",vin);
//    }
//
    /**
     * 车辆下线 - 删除缓存
     */
    public void deleteCarCache(String cacheName) {
        if (!hasCarVinCache(cacheName,null)) {
            log.warn("车辆编码:{},本地缓存不存在该车辆信息...", cacheName);
            return;
        }
        cacheManager.getCache(cacheName).invalidate();
        log.info("车辆编码:{},本地缓存删除完成...", cacheName);
    }

    /**
     * 获取车辆信息缓存
     */
    public Object getCarCache(String cacheName, String key) {
        if (!hasCarVinCache(cacheName, key)){
            log.warn("车辆编码:{},本地缓存不存在该车辆信息...",cacheName);
            return null;
        }
        return cacheManager.getCache(cacheName).get(key).get();
    }

    /**
     * 获取车辆信息缓存
     */
    public <T> T getCarCache(String cacheName, String key, Class<T> type) {
        if (!hasCarVinCache(cacheName,key)){
            log.warn("车辆编码:{},本地缓存不存在该车辆信息...",cacheName);
            return null;
        }
        return cacheManager.getCache(cacheName).get(key, type);
    }

    /**
     * 判断缓存存在与否
     */
    public Boolean hasCarVinCache(String cacheName,String key) {
        boolean notEmpty = ObjectUtils.isNotEmpty(cacheManager.getCache(cacheName));
        if (notEmpty && StringUtils.isNotEmpty(key)){
            return ObjectUtils.isNotEmpty(cacheManager.getCache(cacheName).get(key).get());
        }
        return notEmpty;

    }

}
