package com.muyu.data.processing.strategy.core;

import com.muyu.data.processing.domain.Temporary1;
import com.muyu.data.processing.domain.Temporary2;
import com.muyu.data.processing.strategy.abstractStrategyRouter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * 开始节点
 *
 * @Author: 胡杨
 * @Name: StartStrategy
 * @Description: 策略路由实现
 * @CreatedDate: 2024/9/28 上午10:39
 * @FilePath: com.muyu.data.processing.strategy.impl
 *                              开始节点
 *                                 ↓
 *                             基础校验节点
 *                                 ↓
 *                              路由节点    ←      ←        ←        ←      ←    ←
 *          ↙           ↙          ↓       ↘       ↘
 *     数据处理节点 预警处理节点 故障处理节点 围栏处理节点 实时数据数据处理节点             ↑
 *         ↓           ↓          ↓        ↓           ↓
 *  数据持久化处理节点 预警处理节点 故障处理节点 围栏处理节点 实时数据数据处理节点           ↑
 *         ↓           ↓          ↓        ↓           ↓
 *         ↓     预警通知节点 故障通知节点 围栏通知节点 实时数据处理节点                 ↑
 *         ↓           ↘          ↓        ↙           ↙
 *         ↓                      ↓                                            ↑
 *         →      →     →      路由节点     →      →     →       →      →     →
 *                                ↓
 *                             结束节点
 */

@Slf4j
@Component
public class StartStrategy extends abstractStrategyRouter<Temporary1, Temporary2> {
    @Override
    protected StrategyMapper<Temporary1, Temporary2> registerStrategy() {
        return param -> new BasicStrategy();
    }

}
